@@ -19,13 +19,13 @@ def visualize_all_datasets(df):
     plt.show()
 
 
-def visualize_dataset(df):
+def visualize_dataset(df, name):
     fig = plt.figure()
     ax = fig.add_axes([0.06, 0.06, 0.94, 0.94])
     ax.bar(df['table'], df['num_rows'], color=sns.color_palette("Spectral", len(df['table'])).as_hex())
     ax.axis("on")
     ax.relim()
     ax.autoscale_view()
-    ax.set_title(f'Dataset ({df["dataset"][0]})')
+    ax.set_title(f'Dataset ({name})')
     ax.set_yscale('log')
     plt.show()
